package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.BomanReservatConfig;

/**
 * 预约配置主Mapper接口
 * 
 * @author boman
 * @date 2023-11-02
 */
public interface BomanReservatConfigMapper 
{
    /**
     * 查询预约配置主
     * 
     * @param reservatConfigId 预约配置主主键
     * @return 预约配置主
     */
    public BomanReservatConfig selectBomanReservatConfigByReservatConfigId(Long reservatConfigId);

    /**
     * 查询预约配置主列表
     * 
     * @param bomanReservatConfig 预约配置主
     * @return 预约配置主集合
     */
    public List<BomanReservatConfig> selectBomanReservatConfigList(BomanReservatConfig bomanReservatConfig);

    /**
     * 新增预约配置主
     * 
     * @param bomanReservatConfig 预约配置主
     * @return 结果
     */
    public int insertBomanReservatConfig(BomanReservatConfig bomanReservatConfig);

    /**
     * 修改预约配置主
     * 
     * @param bomanReservatConfig 预约配置主
     * @return 结果
     */
    public int updateBomanReservatConfig(BomanReservatConfig bomanReservatConfig);

    /**
     * 删除预约配置主
     * 
     * @param reservatConfigId 预约配置主主键
     * @return 结果
     */
    public int deleteBomanReservatConfigByReservatConfigId(Long reservatConfigId);

    /**
     * 批量删除预约配置主
     * 
     * @param reservatConfigIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBomanReservatConfigByReservatConfigIds(Long[] reservatConfigIds);
}
